@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The extended API of QDBM
- *                                                      Copyright (C) 2000-2005 Mikio Hirabayashi
+ *                                                      Copyright (C) 2000-2006 Mikio Hirabayashi
  * This file is part of QDBM, Quick Database Manager.
  * QDBM is free software; you can redistribute it and/or modify it under the terms of the GNU
  * Lesser General Public License as published by the Free Software Foundation; either version
@@ -24,6 +24,14 @@ extern "C" {
 
 #include <depot.h>
 #include <stdlib.h>
+#include <time.h>
+
+
+#if defined(_MSC_VER) && !defined(QDBM_INTERNAL) && !defined(QDBM_STATIC)
+#define MYEXTERN extern __declspec(dllimport)
+#else
+#define MYEXTERN extern
+#endif
 
 
 
@@ -34,7 +42,7 @@ extern "C" {
 
 typedef struct {                         /* type of structure for the database handle */
   char *name;                            /* name of the database directory */
-  int wmode;                             /* whether writable or not */
+  int wmode;                             /* whether to be writable */
   int inode;                             /* inode of the database directory */
   DEPOT *attr;                           /* database handle for attributes */
   DEPOT **depots;                        /* handles of the record database */
@@ -193,7 +201,7 @@ char *criternext(CURIA *curia, int *sp);
    `curia' specifies a database handle connected as a writer.
    `align' specifies the size of alignment.
    If successful, the return value is true, else, it is false.
-   If alignment is set to a database, the efficiency of overwriting values are improved.
+   If alignment is set to a database, the efficiency of overwriting values is improved.
    The size of alignment is suggested to be average size of the values of the records to be
    stored.  If alignment is positive, padding whose size is multiple number of the alignment
    is placed.  If alignment is negative, as `vsiz' is the size of a value, the size of padding
@@ -202,6 +210,15 @@ char *criternext(CURIA *curia, int *sp);
 int crsetalign(CURIA *curia, int align);
 
 
+/* Set the size of the free block pool of a database handle.
+   `curia' specifies a database handle connected as a writer.
+   `size' specifies the size of the free block pool of a database.
+   If successful, the return value is true, else, it is false.
+   The default size of the free block pool is 16.  If the size is greater, the space efficiency
+   of overwriting values is improved with the time efficiency sacrificed. */
+int crsetfbpsiz(CURIA *curia, int size);
+
+
 /* Synchronize updating contents with the files and the devices.
    `curia' specifies a database handle connected as a writer.
    If successful, the return value is true, else, it is false.
@@ -283,7 +300,7 @@ int crinode(CURIA *curia);
 /* Get the last modified time of a database.
    `curia' specifies a database handle.
    The return value is the last modified time of the database. */
-int crmtime(CURIA *curia);
+time_t crmtime(CURIA *curia);
 
 
 /* Remove a database directory.
@@ -415,12 +432,14 @@ int crgetflags(CURIA *curia);
 
 /* Set flags of a database.
    `curia' specifies a database handle connected as a writer.
-   `flags' specifies flags to set.
+   `flags' specifies flags to set.  Least ten bits are reserved for internal use.
    If successful, the return value is true, else, it is false. */
 int crsetflags(CURIA *curia, int flags);
 
 
 
+#undef MYEXTERN
+
 #if defined(__cplusplus)                 /* export for C++ */
 }
 #endif
